@@ -17,3 +17,10 @@ def slugify_domain(fn):
     def wrapper(*args, **kwargs):
         return text.slugify(fn(*args, **kwargs), allow_dots=True)
     return wrapper
+
+
+def slugify_unicode(fn):
+    @wraps(fn)
+    def wrapper(*args, **kwargs):
+        return text.slugify(fn(*args, **kwargs), allow_unicode=True)
+    return wrapper
